summaryrefslogtreecommitdiffstats
path: root/src/activityviewer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/activityviewer.h')
-rw-r--r--src/activityviewer.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/src/activityviewer.h b/src/activityviewer.h
index e027ee0..f1511b5 100644
--- a/src/activityviewer.h
+++ b/src/activityviewer.h
@@ -9,24 +9,24 @@
#include <config.h>
#endif
-#include <kapplication.h>
-#include <kmainwindow.h>
-#include <klistview.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
+#include <tdelistview.h>
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQLineEdit;
class TQComboBox;
class TQCheckBox;
-class KListView;
+class TDEListView;
class TQPushButton;
class TQLabel;
-class KProcess;
-class KConfig;
+class TDEProcess;
+class TDEConfig;
class KURLRequester;
-class KListViewItem;
-class KListViewSearchLine;
+class TDEListViewItem;
+class TDEListViewSearchLine;
/**
@@ -62,7 +62,7 @@ public:
TQString getWhen(TQString);
TQString getSelectedVirusName();
void insertItem(const TQString &date, const TQString &type, const TQString &event, const TQString &file);
- KListViewSearchLine* kLineEdit1;
+ TDEListViewSearchLine* kLineEdit1;
protected:
/**
@@ -76,14 +76,14 @@ protected:
* This function is called when it is time for the app to save its
* properties for session management purposes.
*/
- //void saveProperties(KConfig *);
+ //void saveProperties(TDEConfig *);
/**
* This function is called when this app is restored. The KConfig
* object points to the session management config file that was saved
* with @ref saveProperties
*/
- //void readProperties(KConfig *);
+ //void readProperties(TDEConfig *);
private slots:
@@ -100,8 +100,8 @@ private:
//ActivityviewerView *m_view;
/* KPrinter *m_printer;
- KToggleAction *m_toolbarAction;
- KToggleAction *m_statusbarAction;*/
+ TDEToggleAction *m_toolbarAction;
+ TDEToggleAction *m_statusbarAction;*/
signals:
@@ -119,12 +119,12 @@ private:
TQComboBox *check_combo, *days_combo;
KURLRequester *dir_combo;
TQCheckBox *recursive_box;
- KListView *currentbox;
+ TDEListView *currentbox;
TQPushButton *search_button, *cancel_button, *refresh_button, *search_button3, *cancel_button3;
TQLabel *status_label, *matches_label;
- KProcess *childproc;
+ TDEProcess *childproc;
TQString buf;
- KConfig* config;
+ TDEConfig* config;
TQStringList lastQuarItems;
TQStringList lastHistoryItems;
TQStringList lastQuarLocations;
@@ -136,10 +136,10 @@ private:
};
- class EventListItem : public KListViewItem
+ class EventListItem : public TDEListViewItem
{
public:
- EventListItem( KListView *parent, TQString label1, TQString label2 = TQString::null, TQString label3 = TQString::null, TQString label4 = TQString::null);
+ EventListItem( TDEListView *parent, TQString label1, TQString label2 = TQString::null, TQString label3 = TQString::null, TQString label4 = TQString::null);
~EventListItem();
void paintCell ( TQPainter * p, const TQColorGroup & cg, int column, int width, int align );
@@ -76,14 +76,14 @@ protected:
/**
- * This function is called when this app is restored. The KConfig
+ * This function is called when this app is restored. The TDEConfig
* object points to the session management config file that was saved
* with @ref saveProperties